polyfemos.back.station.Stations — polyfemos 0.3.29 documentation

# polyfemos.back.station.Stations

class `polyfemos.back.station.` `Stations`

  Bases: `object`

  Class for containing and handling multiple `Station` instances

  Public Methods

  `__init__`()
  `add_parameter`(parameter)

    Adds `parameter` to the last station with id `self.__last_id`

    Parameters

      parameter (`Parameter`) –

  `add_station`(station)

    Adds `station` to `self.__stations`. If successsfully added, the id of the `station` is saved as `self.__last_id`. `self.__last_id` will always contain the is of the last successfully added station.

    Parameters

      station (`Station`) –

    Return type

      bool

    Returns

      `True` if `station` was successfully added to the `self.__stations`

  `get_station`(network_code, station_code, t0)
    Parameters

      - network_code (str) –

      - station_code (str) –

      - t0 (`Ordinal`) –

    Return type

      `Station`

    Returns

      returns station instances matching the given `network_code` and `station_code`, and including `t0` within it’s time interval